import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class ContractSubscriptionsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Subscribe to contract events and transactions
     * Subscribe to contract events and transactions
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @returns any Default Response
     * @throws ApiError
     */
    addContractSubscription(chain: string, contractAddress: string): CancelablePromise<{
        result: {
            chain: string;
            contractAddress: string;
            status: string;
        };
    }>;
    /**
     * Get all subscribed contracts
     * Get all subscribed contracts
     * @returns any Default Response
     * @throws ApiError
     */
    getContractSubscriptions(): CancelablePromise<{
        result: {
            contracts: Array<{
                chainId: number;
                contractAddress: string;
            }>;
            status: string;
        };
    }>;
    /**
     * Get subscribed contract indexed block range
     * Gets the subscribed contract's indexed block range
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @returns any Default Response
     * @throws ApiError
     */
    getContractIndexedBlockRange(chain: string, contractAddress: string): CancelablePromise<{
        result: {
            chain: string;
            contractAddress: string;
            fromBlock: number;
            toBlock: number;
            status: string;
        };
    }>;
    /**
     * Unsubscribe from contract events
     * Unsubscribe from contract events
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @returns any Default Response
     * @throws ApiError
     */
    removeContractSubscription(chain: string, contractAddress: string): CancelablePromise<{
        result: {
            chain: string;
            contractAddress: string;
            status: string;
        };
    }>;
    /**
     * Get latest indexed block for a chain
     * Get latest indexed block for a chain
     * @param chain Chain name or ID
     * @returns any Default Response
     * @throws ApiError
     */
    getLatestBlock(chain: string): CancelablePromise<{
        result: {
            lastIndexedBlock: number;
            status: string;
        };
    }>;
}
