import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class ContractTransactionsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get subscribed contract transaction receipts
     * Get event logs for a subscribed contract
     * @param fromBlock
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @param toBlock
     * @returns any Default Response
     * @throws ApiError
     */
    getContractTransactionReceipts(fromBlock: number, chain: string, contractAddress: string, toBlock?: number): CancelablePromise<{
        result: {
            receipts: Array<{
                chainId: number;
                blockNumber: number;
                contractAddress: string;
                transactionHash: string;
                blockHash: string;
                timestamp: number;
                data: string;
                value: string;
                to: string;
                from: string;
                transactionIndex: number;
                gasUsed: string;
                effectiveGasPrice: string;
                status: number;
            }>;
            status: string;
        };
    }>;
    /**
     * Get subscribed contract transaction receipts
     * Get transaction receipts for a subscribed contract
     * @param fromBlockTimestamp
     * @param contractAddresses
     * @param toBlockTimestamp
     * @returns any Default Response
     * @throws ApiError
     */
    getContractTransactionReceiptsByTimestamp(fromBlockTimestamp: number, contractAddresses?: Array<string>, toBlockTimestamp?: number): CancelablePromise<{
        result: {
            receipts: Array<{
                chainId: number;
                blockNumber: number;
                contractAddress: string;
                transactionHash: string;
                blockHash: string;
                timestamp: number;
                data: string;
                value: string;
                to: string;
                from: string;
                transactionIndex: number;
                gasUsed: string;
                effectiveGasPrice: string;
                status: number;
            }>;
            status: string;
        };
    }>;
    /**
     * Get contract paginated transaction receipts for subscribed contract
     * Get contract paginated transaction receipts for subscribed contract
     * @param cursor
     * @param pageSize
     * @param contractAddresses
     * @returns any Default Response
     * @throws ApiError
     */
    pageTransactionReceipts(cursor?: string, pageSize?: number, contractAddresses?: Array<string>): CancelablePromise<{
        result: {
            cursor?: string;
            receipts: Array<{
                chainId: number;
                blockNumber: number;
                contractAddress: string;
                transactionHash: string;
                blockHash: string;
                timestamp: number;
                data: string;
                value: string;
                to: string;
                from: string;
                transactionIndex: number;
                gasUsed: string;
                effectiveGasPrice: string;
                status: number;
            }>;
            status: string;
        };
    }>;
}
