import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class DeployService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Deploy Edition
     * Deploy an Edition contract.
     * @param chain Chain ID or name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    deployEdition(chain: string, xBackendWalletAddress: string, requestBody: {
        contractMetadata: {
            name: string;
            description?: string;
            image?: string;
            external_link?: string;
            app_uri?: string;
            defaultAdmin?: string;
            seller_fee_basis_points: number;
            fee_recipient: string;
            symbol: string;
            platform_fee_basis_points: number;
            platform_fee_recipient: string;
            primary_sale_recipient?: string;
            trusted_forwarders: Array<string>;
        };
        /**
         * Version of the contract to deploy. Defaults to latest.
         */
        version?: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            queueId?: string;
            deployedAddress?: string;
        };
    }>;
    /**
     * Deploy Edition Drop
     * Deploy an Edition Drop contract.
     * @param chain Chain ID or name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    deployEditionDrop(chain: string, xBackendWalletAddress: string, requestBody: {
        contractMetadata: {
            name: string;
            description?: string;
            image?: string;
            external_link?: string;
            app_uri?: string;
            defaultAdmin?: string;
            seller_fee_basis_points: number;
            fee_recipient: string;
            merkle?: Record<string, string>;
            symbol: string;
            platform_fee_basis_points: number;
            platform_fee_recipient: string;
            primary_sale_recipient?: string;
            trusted_forwarders: Array<string>;
        };
        /**
         * Version of the contract to deploy. Defaults to latest.
         */
        version?: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            queueId?: string;
            deployedAddress?: string;
        };
    }>;
    /**
     * Deploy Marketplace
     * Deploy a Marketplace contract.
     * @param chain Chain ID or name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    deployMarketplaceV3(chain: string, xBackendWalletAddress: string, requestBody: {
        contractMetadata: {
            name: string;
            description?: string;
            image?: string;
            external_link?: string;
            app_uri?: string;
            defaultAdmin?: string;
            platform_fee_basis_points: number;
            platform_fee_recipient: string;
            trusted_forwarders: Array<string>;
        };
        /**
         * Version of the contract to deploy. Defaults to latest.
         */
        version?: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            queueId?: string;
            deployedAddress?: string;
        };
    }>;
    /**
     * Deploy Multiwrap
     * Deploy a Multiwrap contract.
     * @param chain Chain ID or name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    deployMultiwrap(chain: string, xBackendWalletAddress: string, requestBody: {
        contractMetadata: {
            name: string;
            description?: string;
            image?: string;
            external_link?: string;
            app_uri?: string;
            defaultAdmin?: string;
            seller_fee_basis_points: number;
            fee_recipient: string;
            symbol: string;
            trusted_forwarders: Array<string>;
        };
        /**
         * Version of the contract to deploy. Defaults to latest.
         */
        version?: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            queueId?: string;
            deployedAddress?: string;
        };
    }>;
    /**
     * Deploy NFT Collection
     * Deploy an NFT Collection contract.
     * @param chain Chain ID or name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    deployNftCollection(chain: string, xBackendWalletAddress: string, requestBody: {
        contractMetadata: {
            name: string;
            description?: string;
            image?: string;
            external_link?: string;
            app_uri?: string;
            defaultAdmin?: string;
            seller_fee_basis_points: number;
            fee_recipient: string;
            symbol: string;
            platform_fee_basis_points: number;
            platform_fee_recipient: string;
            primary_sale_recipient?: string;
            trusted_forwarders: Array<string>;
        };
        /**
         * Version of the contract to deploy. Defaults to latest.
         */
        version?: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            queueId?: string;
            deployedAddress?: string;
        };
    }>;
    /**
     * Deploy NFT Drop
     * Deploy an NFT Drop contract.
     * @param chain Chain ID or name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    deployNftDrop(chain: string, xBackendWalletAddress: string, requestBody: {
        contractMetadata: {
            name: string;
            description?: string;
            image?: string;
            external_link?: string;
            app_uri?: string;
            defaultAdmin?: string;
            seller_fee_basis_points: number;
            fee_recipient: string;
            merkle?: Record<string, string>;
            symbol: string;
            platform_fee_basis_points: number;
            platform_fee_recipient: string;
            primary_sale_recipient?: string;
            trusted_forwarders: Array<string>;
        };
        /**
         * Version of the contract to deploy. Defaults to latest.
         */
        version?: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            queueId?: string;
            deployedAddress?: string;
        };
    }>;
    /**
     * Deploy Pack
     * Deploy a Pack contract.
     * @param chain Chain ID or name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    deployPack(chain: string, xBackendWalletAddress: string, requestBody: {
        contractMetadata: {
            name: string;
            description?: string;
            image?: string;
            external_link?: string;
            app_uri?: string;
            defaultAdmin?: string;
            seller_fee_basis_points: number;
            fee_recipient: string;
            symbol: string;
            platform_fee_basis_points: number;
            platform_fee_recipient: string;
            trusted_forwarders: Array<string>;
        };
        /**
         * Version of the contract to deploy. Defaults to latest.
         */
        version?: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            queueId?: string;
            deployedAddress?: string;
        };
    }>;
    /**
     * Deploy Signature Drop
     * Deploy a Signature Drop contract.
     * @param chain Chain ID or name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    deploySignatureDrop(chain: string, xBackendWalletAddress: string, requestBody: {
        contractMetadata: {
            name: string;
            description?: string;
            image?: string;
            external_link?: string;
            app_uri?: string;
            defaultAdmin?: string;
            seller_fee_basis_points: number;
            fee_recipient: string;
            merkle?: Record<string, string>;
            symbol: string;
            platform_fee_basis_points: number;
            platform_fee_recipient: string;
            primary_sale_recipient?: string;
            trusted_forwarders: Array<string>;
        };
        /**
         * Version of the contract to deploy. Defaults to latest.
         */
        version?: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            queueId?: string;
            deployedAddress?: string;
        };
    }>;
    /**
     * Deploy Split
     * Deploy a Split contract.
     * @param chain Chain ID or name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    deploySplit(chain: string, xBackendWalletAddress: string, requestBody: {
        contractMetadata: {
            name: string;
            description?: string;
            image?: string;
            external_link?: string;
            app_uri?: string;
            defaultAdmin?: string;
            recipients: Array<{
                address: string;
                sharesBps: number;
            }>;
            trusted_forwarders: Array<string>;
        };
        /**
         * Version of the contract to deploy. Defaults to latest.
         */
        version?: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            queueId?: string;
            deployedAddress?: string;
        };
    }>;
    /**
     * Deploy Token
     * Deploy a Token contract.
     * @param chain Chain ID or name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    deployToken(chain: string, xBackendWalletAddress: string, requestBody: {
        contractMetadata: {
            name: string;
            description?: string;
            image?: string;
            external_link?: string;
            app_uri?: string;
            defaultAdmin?: string;
            symbol: string;
            platform_fee_basis_points: number;
            platform_fee_recipient: string;
            primary_sale_recipient?: string;
            trusted_forwarders: Array<string>;
        };
        /**
         * Version of the contract to deploy. Defaults to latest.
         */
        version?: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            queueId?: string;
            deployedAddress?: string;
        };
    }>;
    /**
     * Deploy Token Drop
     * Deploy a Token Drop contract.
     * @param chain Chain ID or name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    deployTokenDrop(chain: string, xBackendWalletAddress: string, requestBody: {
        contractMetadata: {
            name: string;
            description?: string;
            image?: string;
            external_link?: string;
            app_uri?: string;
            defaultAdmin?: string;
            merkle?: Record<string, string>;
            symbol: string;
            platform_fee_basis_points: number;
            platform_fee_recipient: string;
            primary_sale_recipient?: string;
            trusted_forwarders: Array<string>;
        };
        /**
         * Version of the contract to deploy. Defaults to latest.
         */
        version?: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            queueId?: string;
            deployedAddress?: string;
        };
    }>;
    /**
     * Deploy Vote
     * Deploy a Vote contract.
     * @param chain Chain ID or name
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    deployVote(chain: string, xBackendWalletAddress: string, requestBody: {
        contractMetadata: {
            name: string;
            description?: string;
            image?: string;
            external_link?: string;
            app_uri?: string;
            defaultAdmin?: string;
            voting_delay_in_blocks: number;
            voting_period_in_blocks: number;
            voting_token_address: string;
            voting_quorum_fraction: number;
            proposal_token_threshold: string;
            trusted_forwarders: Array<string>;
        };
        /**
         * Version of the contract to deploy. Defaults to latest.
         */
        version?: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            queueId?: string;
            deployedAddress?: string;
        };
    }>;
    /**
     * Deploy published contract
     * Deploy a published contract to the blockchain.
     * @param chain Chain ID or name
     * @param publisher Address or ENS of the publisher of the contract
     * @param contractName Name of the published contract to deploy
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xAccountAddress Smart account address
     * @param xIdempotencyKey A string that uniquely identifies this transaction. Submitting the same idempotency key will not enqueue a new transaction for 24 hours.
     * @returns any Default Response
     * @throws ApiError
     */
    deployPublished(chain: string, publisher: string, contractName: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Constructor arguments for the deployment.
         */
        constructorParams: Array<any>;
        /**
         * Version of the contract to deploy. Defaults to latest.
         */
        version?: string;
        txOverrides?: {
            /**
             * Amount of native currency to send
             */
            value?: string;
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, xAccountAddress?: string, xIdempotencyKey?: string): CancelablePromise<{
        queueId?: string;
        /**
         * Not all contracts return a deployed address.
         */
        deployedAddress?: string;
        message?: string;
    }>;
    /**
     * Get contract types
     * Get all prebuilt contract types.
     * @returns any Default Response
     * @throws ApiError
     */
    contractTypes(): CancelablePromise<{
        result: Array<string>;
    }>;
}
