import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class KeypairService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * List public keys
     * List the public keys configured with Engine
     * @returns any Default Response
     * @throws ApiError
     */
    list(): CancelablePromise<{
        result: Array<{
            /**
             * A unique identifier for the keypair
             */
            hash: string;
            /**
             * The public key
             */
            publicKey: string;
            /**
             * The keypair algorithm.
             */
            algorithm: string;
            /**
             * A description for the keypair.
             */
            label?: string;
            /**
             * When the keypair was added
             */
            createdAt: string;
            /**
             * When the keypair was updated
             */
            updatedAt: string;
        }>;
    }>;
    /**
     * Add public key
     * Add the public key for a keypair
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    add(requestBody: {
        /**
         * The public key of your keypair beginning with '-----BEGIN PUBLIC KEY-----'.
         */
        publicKey: string;
        algorithm: ('RS256' | 'RS384' | 'RS512' | 'ES256' | 'ES384' | 'ES512' | 'PS256' | 'PS384' | 'PS512');
        label?: string;
    }): CancelablePromise<{
        result: {
            keypair: {
                /**
                 * A unique identifier for the keypair
                 */
                hash: string;
                /**
                 * The public key
                 */
                publicKey: string;
                /**
                 * The keypair algorithm.
                 */
                algorithm: string;
                /**
                 * A description for the keypair.
                 */
                label?: string;
                /**
                 * When the keypair was added
                 */
                createdAt: string;
                /**
                 * When the keypair was updated
                 */
                updatedAt: string;
            };
        };
    }>;
    /**
     * Remove public key
     * Remove the public key for a keypair
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    remove(requestBody: {
        hash: string;
    }): CancelablePromise<{
        result: {
            success: boolean;
        };
    }>;
}
