import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class RelayerService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get all meta-transaction relayers
     * Get all meta-transaction relayers
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(): CancelablePromise<{
        result: Array<{
            id: string;
            name: (string | null);
            chainId: string;
            backendWalletAddress: string;
            allowedContracts: (Array<string> | null);
            allowedForwarders: (Array<string> | null);
        }>;
    }>;
    /**
     * Create a new meta-transaction relayer
     * Create a new meta-transaction relayer
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    create(requestBody: {
        name?: string;
        chain: string;
        /**
         * The address of the backend wallet to use for relaying transactions.
         */
        backendWalletAddress: string;
        allowedContracts?: Array<string>;
        allowedForwarders?: Array<string>;
    }): CancelablePromise<{
        result: {
            relayerId: string;
        };
    }>;
    /**
     * Revoke a relayer
     * Revoke a relayer
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    revoke(requestBody: {
        id: string;
    }): CancelablePromise<{
        result: {
            success: boolean;
        };
    }>;
    /**
     * Update a relayer
     * Update a relayer
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    update(requestBody: {
        id: string;
        name?: string;
        chain?: string;
        backendWalletAddress?: string;
        allowedContracts?: Array<string>;
        allowedForwarders?: Array<string>;
    }): CancelablePromise<{
        result: {
            success: boolean;
        };
    }>;
    /**
     * Relay a meta-transaction
     * Relay an EIP-2771 meta-transaction
     * @param relayerId
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    relay(relayerId: string, requestBody?: ({
        type: 'forward';
        request: {
            from: string;
            to: string;
            value: string;
            gas: string;
            nonce: string;
            data: string;
            chainid?: string;
        };
        signature: string;
        forwarderAddress: string;
    } | {
        type: 'permit';
        request: {
            to: string;
            owner: string;
            spender: string;
            value: string;
            nonce: string;
            deadline: string;
        };
        signature: string;
    } | {
        type: 'execute-meta-transaction';
        request: {
            from: string;
            to: string;
            data: string;
        };
        signature: string;
    })): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
}
