import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class WebhooksService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get all webhooks configured
     * Get all webhooks configuration data set up on Engine
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(): CancelablePromise<{
        result: Array<{
            url: string;
            name: (string | null);
            secret?: string;
            eventType: string;
            active: boolean;
            createdAt: string;
            id: number;
        }>;
    }>;
    /**
     * Create a webhook
     * Create a webhook to call when certain blockchain events occur.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    create(requestBody: {
        /**
         * Webhook URL
         */
        url: string;
        name?: string;
        eventType: ('queued_transaction' | 'sent_transaction' | 'mined_transaction' | 'errored_transaction' | 'cancelled_transaction' | 'all_transactions' | 'backend_wallet_balance' | 'auth');
    }): CancelablePromise<{
        result: {
            url: string;
            name: string;
            createdAt: string;
            eventType: string;
            secret?: string;
            id: number;
        };
    }>;
    /**
     * Revoke webhook
     * Revoke a Webhook
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    revoke(requestBody: {
        id: number;
    }): CancelablePromise<{
        result: {
            success: boolean;
        };
    }>;
    /**
     * Get webhooks event types
     * Get the all the webhooks event types
     * @returns any Default Response
     * @throws ApiError
     */
    getEventTypes(): CancelablePromise<{
        result: Array<('queued_transaction' | 'sent_transaction' | 'mined_transaction' | 'errored_transaction' | 'cancelled_transaction' | 'all_transactions' | 'backend_wallet_balance' | 'auth')>;
    }>;
}
